@@ -1,5 +1,7 @@
+from __future__ import print_function
 import time
 
+
 def go():
     import namespace_get
     a = namespace_get.get_cached_value()
@@ -13,13 +15,11 @@ def go():
     time.sleep(0.3)
     d = test_namespacing_files.namespace_get.get_cached_value()
 
-    print a
-    print b
-    print c
-    print d
-
-    assert a==b, 'Basic caching problem - should never happen'
-    assert c==d, 'Basic caching problem - should never happen'
-    assert a==c, 'Namespaces not consistent when using different import paths'
-
+    print(a)
+    print(b)
+    print(c)
+    print(d)
 
+    assert a == b, 'Basic caching problem - should never happen'
+    assert c == d, 'Basic caching problem - should never happen'
+    assert a == c, 'Namespaces not consistent when using different import paths'
